Learn R Programming

greenSD (version 0.1.1)

check_available_urban: Get all of the urban areas in the Greenspace Seasonality Data Cube

Description

This function returns all of the urban areas in the Greenspace Seasonality Data Cube dataset.

Usage

check_available_urban(test = FALSE)

Value

dataframe

Arguments

test

logical. (ignored) Only for testing.

References

Wu, S., Song, Y., An, J. et al. High-resolution greenspace dynamic data cube from Sentinel-2 satellites over 1028 global major cities. Sci Data 11, 909 (2024). https://doi.org/10.1038/s41597-024-03746-7

Examples

Run this code
check_available_urban(test = TRUE)

Run the code above in your browser using DataLab